pub struct ReadTxn<'a> { /* private fields */ }Expand description
Concurrent read view pinned at a revision ceiling.
Implementations
Sourceimpl<'a> ReadTxn<'a>
impl<'a> ReadTxn<'a>
Sourcepub fn new(db: &'a InfiniteDb) -> Self
pub fn new(db: &'a InfiniteDb) -> Self
Pin reads at the current database revision on main.
Sourcepub fn on_branch(self, branch: BranchId) -> Self
pub fn on_branch(self, branch: BranchId) -> Self
Read through a branch overlay instead of main.
Sourcepub fn as_of(self, rev: RevisionId) -> Self
pub fn as_of(self, rev: RevisionId) -> Self
Override the revision ceiling for this read view.
Sourcepub fn query(&self, space: SpaceId) -> Result<Vec<Record>>
pub fn query(&self, space: SpaceId) -> Result<Vec<Record>>
Query all live records in space within this read view.
Sourcepub fn query_bbox(
&self,
space: SpaceId,
min: DimensionVector,
max: DimensionVector,
) -> Result<Vec<Record>>
pub fn query_bbox( &self, space: SpaceId, min: DimensionVector, max: DimensionVector, ) -> Result<Vec<Record>>
Bounding-box query within this read view.